<?php
header('Content-Type: application/json');

// Включение отображения ошибок PHP для диагностики
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

function getRandomUserAgent() {
    $userAgents = [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 YaBrowser/24.12.0.0 Safari/537.36",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Safari/537.36",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:115.0) Gecko/20100101 Firefox/115.0",
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.2 Safari/605.1.15",
        "Mozilla/5.0 (iPhone; CPU iPhone OS 16_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.3 Mobile/15E148 Safari/604.1",
        "Mozilla/5.0 (Linux; Android 13; SM-G991B) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Mobile Safari/537.36",
        "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Safari/537.36",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Edge/117.0.2045.41",
        "Mozilla/5.0 (iPad; CPU OS 16_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.3 Mobile/15E148 Safari/604.1"
    ];
    return $userAgents[array_rand($userAgents)];
}

function logRequestResponse($cardData, $response, $httpCode) {
    $logFilePath = __DIR__ . '/request_response_log.txt';
    $timestamp = date('Y-m-d H:i:s');
    $logEntry = "[$timestamp] Card: $cardData\n";
    $logEntry .= "[$timestamp] HTTP Code: $httpCode\n";
    $logEntry .= "[$timestamp] Response: " . json_encode($response, JSON_PRETTY_PRINT) . "\n";
    $logEntry .= "----------------------------------------\n";

    // Проверка существования файла
    if (!file_exists($logFilePath)) {
        error_log("Log file does not exist: $logFilePath");
        if (touch($logFilePath) === false) {
            error_log("Failed to create log file: $logFilePath");
            return;
        }
        error_log("Log file created: $logFilePath");
    }

    // Проверка возможности записи в файл
    if (!is_writable($logFilePath)) {
        error_log("Log file is not writable: $logFilePath");
        return;
    }

    if (file_put_contents($logFilePath, $logEntry, FILE_APPEND) === false) {
        error_log("Failed to write to log file: $logFilePath");
    }
}

function checkCard($cardData, $apiKey) {
    $ch = curl_init();
    $url = "https://api.chkr.cc/";
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query([
        'data' => $cardData,
        'key' => $apiKey // Убедитесь, что ключ корректен
    ]));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_USERAGENT, getRandomUserAgent());
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/x-www-form-urlencoded',
        'Accept-Encoding: gzip' // Добавляем поддержку Gzip
    ]);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_MAXREDIRS, 5);
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);
    curl_setopt($ch, CURLOPT_ENCODING, ''); // Автоматическое распаковывание сжатых данных

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    // Декодирование Gzip, если необходимо
    if ($httpCode == 200 && strpos($response, "\x1f\x8b") === 0) {
        $response = gzdecode($response);
    }

    return [
        'cardData' => $cardData,
        'response' => $response,
        'httpCode' => $httpCode
    ];
}

function processCards($cards, $apiKey) {
    $successCards = [];
    $noResponseCards = [];
    $deadCards = [];
    $unknownCards = [];
    $logEntries = [];

    $totalCards = count($cards);
    $processedCards = 0;

    error_log("Total cards to process: $totalCards");

    foreach ($cards as $index => $card) {
        error_log("Processing card $card at index $index");

        $result = checkCard($card, $apiKey);
        $logEntries[] = $result;

        if ($result['httpCode'] == 200) {
            // Декодирование Gzip, если необходимо
            if (strpos($result['response'], "\x1f\x8b") === 0) {
                $result['response'] = gzdecode($result['response']);
            }

            $jsonResponse = json_decode($result['response'], true);
            if ($jsonResponse && isset($jsonResponse['status'])) {
                if ($jsonResponse['status'] == 'Live') {
                    $successCards[] = $card;
                } elseif ($jsonResponse['status'] == 'Unknown') {
                    $unknownCards[] = $card;
                } else {
                    $deadCards[] = $card;
                }
            } else {
                $noResponseCards[] = $card;
            }
        } else {
            $noResponseCards[] = $card;
        }
        $processedCards++;

        // Задержка между запросами
        usleep(500000); // 0.5 секунды
    }

    // Запись всех логов после завершения проверки всех карт
    foreach ($logEntries as $entry) {
        logRequestResponse($entry['cardData'], $entry['response'], $entry['httpCode']);
    }

    error_log("Processed cards: $processedCards");
    error_log("Success cards: " . count($successCards));
    error_log("No response cards: " . count($noResponseCards));
    error_log("Dead cards: " . count($deadCards));
    error_log("Unknown cards: " . count($unknownCards));

    return [
        'successCards' => $successCards,
        'noResponseCards' => $noResponseCards,
        'deadCards' => $deadCards,
        'unknownCards' => $unknownCards
    ];
}

function validateCardNumber($cardNumber) {
    // Простая валидация формата карты
    return preg_match('/^\d{16}\|\d{2}\|\d{4}\|\d{3}$/', $cardNumber) === 1;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $apiKey = ''; // Убедитесь, что ключ корректен
    $cardNumbers = explode("\n", trim($_POST['cardNumbers']));
    $validCards = array_filter($cardNumbers, 'validateCardNumber');
    error_log("Received card numbers: " . implode(", ", $cardNumbers));
    error_log("Valid card numbers: " . implode(", ", $validCards));
    $results = processCards($validCards, $apiKey);
    echo json_encode($results);
}
?>