<?php
session_start();

if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

$session_id = isset($_GET['session_id']) ? intval($_GET['session_id']) : 0;

if (!$session_id) {
    header('Location: index.php');
    exit;
}

//    
$host = 'localhost';
$dbname = 'sessions';
$username = 'root';
$password = '';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    $stmt = $pdo->prepare("SELECT * FROM sessions WHERE id = :session_id");
    $stmt->bindParam(':session_id', $session_id);
    $stmt->execute();
    $session = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$session) {
        header('Location: index.php');
        exit;
    }

    //     
    // ,      
    $messages = [
        ['sender' => 'User', 'text' => '!'],
        ['sender' => 'Bot', 'text' => '!    ?']
    ];
} catch (PDOException $e) {
    die('  : ' . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title></title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <div class="container mt-5">
        <h1></h1>
        <div id="messages-container">
            <?php foreach ($messages as $message): ?>
                <div class="alert alert-info">
                    <strong><?php echo htmlspecialchars($message['sender']); ?></strong>: <?php echo htmlspecialchars($message['text']); ?>
                </div>
            <?php endforeach; ?>
        </div>
        <form id="message-form">
            <input type="text" id="message-input" placeholder=" " required>
            <button type="submit" class="btn btn-primary"></button>
        </form>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script>
        $(document).ready(function() {
            function fetchMessages() {
                $.getJSON('api/messages.php?session_id=<?php echo $session_id; ?>', function(data) {
                    let chatContainer = $('#messages-container');
                    chatContainer.empty();
                    data.messages.forEach(message => {
                        let messageElement = `
                            <div class="alert alert-info">
                                <strong>${message.sender}</strong>: ${message.text}
                            </div>
                        `;
                        chatContainer.append(messageElement);
                    });
                });
            }

            fetchMessages();

            $('#message-form').on('submit', function(e) {
                e.preventDefault();
                let messageText = $('#message-input').val();
                $.post('api/send_message.php', { session_id: <?php echo $session_id; ?>, text: messageText }, function(response) {
                    fetchMessages();
                    $('#message-input').val('');
                }).fail(function(error) {
                    alert('   : ' + error.responseText);
                });
            });
        });
    </script>
</body>
</html>